<?php

namespace App\Controller\Frontend;

use App\Entity\Dream;
use App\Entity\ProjectBoost;
use App\Entity\ProjectInspiring;
use App\Entity\Revolt;
use App\Form\ContactForm;
use App\Form\IndividualForm;
use App\Form\SearchListForm;
use App\Repository\DreamStore;
use App\Repository\ProjectBoostStore;
use App\Repository\ProjectInspiringStore;
use App\Repository\RevoltStore;
use Doctrine\ORM\EntityManagerInterface;
use Knp\Component\Pager\PaginatorInterface;
use Symfony\Bundle\FrameworkBundle\Controller\AbstractController;
use Symfony\Component\HttpFoundation\JsonResponse;
use Symfony\Component\HttpFoundation\Response;
use App\Entity\Site\Page;
use Symfony\Component\Mailer\MailerInterface;
use Symfony\Component\Mime\Email;
use Symfony\Component\HttpFoundation\Request;

class DefaultController extends AbstractController
{
    protected EntityManagerInterface $em;
    protected DreamStore $dreamStore;
    protected RevoltStore $revoltStore;
    protected ProjectBoostStore $projectBoostStore;
    protected ProjectInspiringStore $projectInspiringStore;
    protected PaginatorInterface $paginator;

    public function __construct(
        EntityManagerInterface $em,
        DreamStore $dreamStore,
        RevoltStore $revoltStore,
        ProjectBoostStore $projectBoostStore,
        ProjectInspiringStore $projectInspiringStore,
        PaginatorInterface $paginator
    ) {
        $this->em = $em;
        $this->dreamStore = $dreamStore;
        $this->revoltStore = $revoltStore;
        $this->projectBoostStore = $projectBoostStore;
        $this->projectInspiringStore = $projectInspiringStore;
        $this->paginator = $paginator;
    }

    public function home()
    {
        return $this->render('frontend/home.html.twig');
    }

    public function cartoInteractive()
    {
        return $this->render(
            'frontend/carto-int.html.twig',
            [
                'nbContrib' => $this->countContrib()
            ]
        );
    }

    public function cartoListe(Request $request)
    {
        $dreamArray = $revoltArray = $projectBoostArray = $projectInspiringArray = $resultArray = $resultArrayPagination = array();

        $form = $this->createForm(SearchListForm::class);
        $form->handleRequest($request);

        if ($form->isSubmitted() && $form->isValid()) {
            $data = $form->getData();
            $page = $data['page'];
            $description = $data['search'];
            $categoryArray = $data['category'];
            $territoryArray = $data['territory'];
            $thematicArray = $data['thematic'];

            if (in_array('dream', $categoryArray) || empty($categoryArray)) {
                $dreamArray = $this->dreamStore->filterSearch($description, $territoryArray, $thematicArray);
            }
            if (in_array('revolt', $categoryArray) || empty($categoryArray)) {
                $revoltArray = $this->revoltStore->filterSearch($description, $territoryArray, $thematicArray);
            }
            if (in_array('projectBoost', $categoryArray) || empty($categoryArray)) {
                $projectBoostArray = $this->projectBoostStore->filterSearch(
                    $description,
                    $territoryArray,
                    $thematicArray
                );
            }
            if (in_array('projectInspiring', $categoryArray) || empty($categoryArray)) {
                $projectInspiringArray = $this->projectInspiringStore->filterSearch(
                    $description,
                    $territoryArray,
                    $thematicArray
                );
            }

            $resultArray = array_merge($dreamArray, $revoltArray, $projectBoostArray, $projectInspiringArray);

            $resultArrayPagination = $this->paginator->paginate(
                $resultArray,
                $page,
                10
            );
        }

        return $this->render(
            'frontend/carto-liste.html.twig',
            [
                'form' => $form->createView(),
                'nbContrib' => $this->countContrib(),
                'resultArray' => $resultArrayPagination
            ]
        );
    }

    public function cartoCarte()
    {
        return $this->render(
            'frontend/carto-carte.html.twig',
            [
                'nbContrib' => $this->countContrib()
            ]
        );
    }

    public function contactForm(Request $request, MailerInterface $mailer)
    {
        $form = $this->createForm(ContactForm::class);
        $form->handleRequest($request);
        if ($form->isSubmitted() && $form->isValid() && $form->get('lccap')->getData() == 'blop') {
            $message = '<p>De : ' . $form->get('firstname')->getData() . ' ' . $form->get('lastname')->getData(
                ) . '<br />Email : ' . $form->get('email')->getData() . '<br />Objet : ' . $form->get(
                    'object'
                )->getData() . '</p><p>' . $form->get('message')->getData() . '</p>';

            $email = (new Email())
                ->from('charly@laclic.fr')
                ->from('nepasrepondre@laclic.fr')
                ->replyTo($form->get('email')->getData())
//                ->to('agir@lacooperativedescitoyens.fr')
                ->to('charly@laclic.fr')
                ->subject('Message de contact sur Aux Actes Citoyens !')
                ->text(strip_tags($message))
                ->html($message);

            $mailer->send($email);

            return new JsonResponse(
                [
                    'status' => 'success'
                ]
            );
        }
        return new JsonResponse(
            [
                'status' => 'error'
            ]
        );
    }

    public function contact()
    {
        $form = $this->createForm(ContactForm::class, null, array(
            'action' => $this->generateUrl('app_contact_form')
        ));

        return $this->render('frontend/contact.html.twig', [
            'form' => $form->createView()
        ]);
    }

    public function about()
    {
        return $this->render('frontend/about.html.twig');
    }

    public function contribuate()
    {
        $form = $this->createForm(IndividualForm::class);

        return $this->render(
            'frontend/contribuate.html.twig',
            [
                'nbContrib' => $this->countContrib(),
                'form' => $form->createView()
            ]
        );
    }

    public function mention(): Response
    {
        $pageRepository = $this->em->getRepository(Page::class);

        return $this->render(
            'page/page.html.twig',
            [
                'controller_name' => 'IndexController',
                'page' => $pageRepository->findOneByDevAlias('legal-mention')
            ]
        );
    }

    private function countContrib(): int
    {
        $dreamRepository = $this->em->getRepository(Dream::class);
        $revoltRepository = $this->em->getRepository(Revolt::class);
        $projectBoostRepository = $this->em->getRepository(ProjectBoost::class);
        $projectInspiringRepository = $this->em->getRepository(ProjectInspiring::class);

        $dream = count($dreamRepository->findAll());
        $revolt = count($revoltRepository->findAll());
        $projectBoost = count($projectBoostRepository->findAll());
        $projectInspiring = count($projectBoostRepository->findAll());

        $nbContrib = $dream + $revolt + $projectBoost + $projectInspiring;

        return $nbContrib;
    }

}